==> haskell-rio-prettyprint-0.1.7.0-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-prettyprint
version:              0.1.7.0
visibility:           public
id:                   rio-prettyprint-0.1.7.0-TqQEF5lWy0LgKNmBnjPfa
key:                  rio-prettyprint-0.1.7.0-TqQEF5lWy0LgKNmBnjPfa
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  41dd9c5df046a2c19b9043e2cf6a141e
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.7.0-TqQEF5lWy0LgKNmBnjPfa
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-5BFfk7iI7w6HPWzhbIRzqn
    annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
    ansi-terminal-1.0.2-J3CYMek3QCg8mQRiAxriIL array-0.5.4.0
    base-4.17.2.1 colour-2.3.6-FIgDdqoL5o6H1LR4GaFueC mtl-2.2.2
    path-0.9.5-7YMjxAhDyOXwxfQnBoLO6
    rio-0.1.22.0-LoHMyQLcvof2MQnWPLcQsM text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-prettyprint-0.1.7.0-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-prettyprint
version:              0.1.7.0
visibility:           public
id:                   rio-prettyprint-0.1.7.0-7sgFgrj0gQaGZQ4gC7fVtL
key:                  rio-prettyprint-0.1.7.0-7sgFgrj0gQaGZQ4gC7fVtL
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  022c3cc3b24894652dbc8ff6e2f856ce
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rio-prettyprint-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.7.0-7sgFgrj0gQaGZQ4gC7fVtL
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-6jLf9XnWqJCFwZgyNgcXK5
    annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
    ansi-terminal-1.0.2-2SdInZ2XzOpHxNy7zA9Y2f array-0.5.4.0
    base-4.17.2.1 colour-2.3.6-EOt0HdRSZie5Rsd42PTFgr mtl-2.2.2
    path-0.9.5-CpLa5rTA1sFDkSISiDRSpC
    rio-0.1.22.0-L3kUY6aXNJm8hBohZiDZgU text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
